@@ -1,5 +1,7 @@
 """openbb_akshare OpenBB Platform Provider."""
 
+project_name = __name__
+
 from openbb_core.provider.abstract.provider import Provider
 from openbb_akshare.models.available_indices import AKShareAvailableIndicesFetcher
 from openbb_akshare.models.balance_sheet import AKShareBalanceSheetFetcher
@@ -12,6 +14,7 @@ from openbb_akshare.models.equity_historical import AKShareEquityHistoricalFetch
 from openbb_akshare.models.equity_profile import AKShareEquityProfileFetcher
 from openbb_akshare.models.historical_dividends import AKShareHistoricalDividendsFetcher
 from openbb_akshare.models.income_statement import AKShareIncomeStatementFetcher
+from openbb_akshare.models.price_performance import AKSharePricePerformanceFetcher
 
 # mypy: disable-error-code="list-item"
 
@@ -36,5 +39,6 @@ provider = Provider(
         "EquityInfo": AKShareEquityProfileFetcher,
         "HistoricalDividends": AKShareHistoricalDividendsFetcher,
         "IncomeStatement": AKShareIncomeStatementFetcher,
+        "PricePerformance": AKSharePricePerformanceFetcher,
     }
 )
