@@ -1,6 +1,7 @@
 """AKShare Income Statement Model."""
 
 # pylint: disable=unused-argument
+import pandas as pd
 from datetime import (
     date as dateType,
     datetime,
@@ -32,6 +33,14 @@ class AKShareIncomeStatementQueryParams(IncomeStatementQueryParams):
         default="annual",
         description=QUERY_DESCRIPTIONS.get("period", ""),
     )
+    limit: Optional[int] = Field(
+        default=5,
+        description=QUERY_DESCRIPTIONS.get("limit", ""),
+    )
+    use_cache: bool = Field(
+        default=True,
+        description="Whether to use a cached request. The quote is cached for one hour.",
+    )
 
 
 class AKShareIncomeStatementData(IncomeStatementData):
@@ -41,37 +50,22 @@ class AKShareIncomeStatementData(IncomeStatementData):
         "period_ending": "REPORT_DATE",
         "fiscal_period": "REPORT_TYPE",
         "reported_currency": "CURRENCY",
-        "total_pre_tax_income": "TOTAL_PROFIT",
-        "income_tax_expense": "INCOME_TAX",
-        "consolidated_net_income": "NETPROFIT",
-        "basic_earnings_per_share": "BASIC_EPS",
-        "diluted_earnings_per_share": "DILUTED_EPS",
+        "总营收": "TOTAL_OPERATE_INCOME",
+        "净利润": "PARENT_NETPROFIT"
     }
 
     reported_currency: Optional[str] = Field(
         default=None,
         description="The currency in which the balance sheet was reported.",
     )
-    total_pre_tax_income: Optional[float] = Field(
+    总营收: Optional[float] = Field(
         default=None,
         description="Total pre-tax income.",
     )
-    income_tax_expense: Optional[float] = Field(
+    净利润: Optional[float] = Field(
         default=None,
         description="Income tax expense.",
     )
-    consolidated_net_income: Optional[float] = Field(
-        default=None,
-        description="Consolidated net income.",
-    )
-    basic_earnings_per_share: Optional[float] = Field(
-        default=None,
-        description="Basic earnings per share.",
-    )
-    diluted_earnings_per_share: Optional[float] = Field(
-        default=None,
-        description="Diluted earnings per share.",
-    )
 
     @model_validator(mode="before")
     @classmethod
@@ -98,21 +92,19 @@ class AKShareIncomeStatementFetcher(
         return AKShareIncomeStatementQueryParams(**params)
 
     @staticmethod
-    async def aextract_data(
+    async def extract_data(
         query: AKShareIncomeStatementQueryParams,
         credentials: Optional[Dict[str, str]],
         **kwargs: Any,
     ) -> List[Dict]:
         """Return the raw data from the AKShare endpoint."""
-        import akshare as ak
-        from openbb_akshare.utils.tools import normalize_symbol
 
-        symbol_b, symbol_f, market = normalize_symbol(query.symbol)
-        symbol_em = f"SH{symbol_b}"
-        stock_profit_sheet_by_yearly_em_df = ak.stock_profit_sheet_by_yearly_em(symbol=symbol_em)
-        #income_statement_em = stock_profit_sheet_by_yearly_em_df[["REPORT_DATE", "REPORT_TYPE", "CURRENCY", "TOTAL_OPERATE_COST", "OPERATE_INCOME", "TOTAL_PROFIT", "INCOME_TAX", "NETPROFIT", "BASIC_EPS", "DILUTED_EPS"]]
+        em_df = get_data(query.symbol, query.period, query.use_cache)
 
-        return stock_profit_sheet_by_yearly_em_df.to_dict(orient="records")
+        if query.limit is None:
+            return em_df.to_dict(orient="records")
+        else:
+            return em_df.head(query.limit).to_dict(orient="records")
 
     @staticmethod
     def transform_data(
@@ -123,3 +115,22 @@ class AKShareIncomeStatementFetcher(
             result.pop("symbol", None)
             result.pop("cik", None)
         return [AKShareIncomeStatementData.model_validate(d) for d in data]
+
+def get_data(symbol: str, period: str = "annual", use_cache: bool = True) -> pd.DataFrame:
+    from openbb_akshare import project_name
+    from mysharelib.blob_cache import BlobCache
+    cache = BlobCache(table_name="income_statement", project=project_name)
+    return cache.load_cached_data(symbol, period, use_cache, get_income_statement)
+
+def get_income_statement(symbol: str, period: str = "annual", api_key : Optional[str] = "") -> pd.DataFrame:
+    import akshare as ak
+    from openbb_akshare.utils.helpers import normalize_symbol
+    symbol_b, symbol_f, market = normalize_symbol(symbol)
+    symbol_em = f"{market}{symbol_b}"
+
+    if period == "annual":
+        return ak.stock_profit_sheet_by_yearly_em(symbol=symbol_em)
+    elif period == "quarter":
+        return ak.stock_profit_sheet_by_report_em(symbol=symbol_em)
+    else:
+        raise ValueError("Invalid period. Please use 'annual' or 'quarter'.")
\ No newline at end of file
